Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.cpp	(revision 65286)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.cpp	(revision 65287)
@@ -25,21 +25,16 @@
 
 /* GUI includes: */
+# include "VBoxGlobal.h"
 # include "UIMachine.h"
 # include "UISession.h"
-# include "UIIconPool.h"
-# include "VBoxGlobal.h"
 # include "UIConverter.h"
-# include "UIMessageCenter.h"
 # include "UIInformationItem.h"
 # include "UIInformationModel.h"
 # include "UIInformationDataItem.h"
-# include "UIGraphicsRotatorButton.h"
 
 /* COM includes: */
-# include "COMEnums.h"
 # include "CMedium.h"
-# include "CMachine.h"
+# include "CSerialPort.h"
 # include "CVRDEServer.h"
-# include "CSerialPort.h"
 # include "CAudioAdapter.h"
 # include "CParallelPort.h"
@@ -50,11 +45,8 @@
 # include "CUSBDeviceFilter.h"
 # include "CMediumAttachment.h"
+# include "CSystemProperties.h"
 # include "CUSBDeviceFilters.h"
-# include "CSystemProperties.h"
 # include "CStorageController.h"
 
-/* Other VBox includes: */
-# include <iprt/time.h>
-
 #endif /* !VBOX_WITH_PRECOMPILED_HEADERS */
 
@@ -64,6 +56,6 @@
 *********************************************************************************************************************************/
 
-UIInformationDataItem::UIInformationDataItem(InformationElementType type, const CMachine &machine, const CConsole &console, UIInformationModel *pModel)
-    : m_type(type)
+UIInformationDataItem::UIInformationDataItem(InformationElementType enmType, const CMachine &machine, const CConsole &console, UIInformationModel *pModel)
+    : m_enmType(enmType)
     , m_machine(machine)
     , m_console(console)
@@ -72,29 +64,12 @@
 }
 
-UIInformationDataItem::~UIInformationDataItem()
-{
-}
-
-QVariant UIInformationDataItem::data(const QModelIndex &index, int role) const
-{
-    RT_NOREF(index);
-
-    /* For particular role: */
-    switch (role)
-    {
-        case Qt::DisplayRole:
-        {
-            return gpConverter->toString(m_type);
-        }
-        break;
-
-        case Qt::UserRole + 2:
-        {
-            return m_type;
-        }
-        break;
-
-        default:
-        break;
+QVariant UIInformationDataItem::data(const QModelIndex & /* index */, int role) const
+{
+    /* For particular role: */
+    switch (role)
+    {
+        case Qt::DisplayRole:  return gpConverter->toString(m_enmType);
+        case Qt::UserRole + 2: return m_enmType;
+        default:               break;
     }
 
@@ -122,5 +97,4 @@
             return QString(":/machine_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -131,8 +105,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -160,5 +133,4 @@
             return QString(":/chipset_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -226,8 +198,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -255,7 +226,6 @@
             return QString(":/vrdp_16px.png");
         }
-        break;
-
-        case Qt::UserRole+1:
+
+        case Qt::UserRole + 1:
         {
             UITextTable p_text;
@@ -291,8 +261,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -316,12 +285,10 @@
     switch (role)
     {
-
         case Qt::DecorationRole:
         {
             return QString(":/hd_16px.png");
         }
-        break;
-
-        case Qt::UserRole+1:
+
+        case Qt::UserRole + 1:
         {
             UITextTable p_text;
@@ -361,8 +328,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -390,5 +356,4 @@
             return QString(":/sound_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -405,8 +370,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -434,7 +398,6 @@
             return QString(":/nw_16px.png");
         }
-        break;
-
-        case Qt::UserRole+1:
+
+        case Qt::UserRole + 1:
         {
             UITextTable p_text;
@@ -447,26 +410,26 @@
                 {
                     KNetworkAttachmentType type = adapter.GetAttachmentType();
-                    QString attType = gpConverter->toString (adapter.GetAdapterType())
-                                      .replace (QRegExp ("\\s\\(.+\\)"), " (%1)");
+                    QString attType = gpConverter->toString(adapter.GetAdapterType())
+                                      .replace(QRegExp ("\\s\\(.+\\)"), " (%1)");
                     /* don't use the adapter type string for types that have
                      * an additional symbolic network/interface name field, use
                      * this name instead */
                     if (type == KNetworkAttachmentType_Bridged)
-                        attType = attType.arg (tr ("Bridged adapter, %1",
-                            "details report (network)").arg (adapter.GetBridgedInterface()));
+                        attType = attType.arg(tr("Bridged adapter, %1",
+                            "details report (network)").arg(adapter.GetBridgedInterface()));
                     else if (type == KNetworkAttachmentType_Internal)
-                        attType = attType.arg (tr ("Internal network, '%1'",
-                            "details report (network)").arg (adapter.GetInternalNetwork()));
+                        attType = attType.arg(tr("Internal network, '%1'",
+                            "details report (network)").arg(adapter.GetInternalNetwork()));
                     else if (type == KNetworkAttachmentType_HostOnly)
-                        attType = attType.arg (tr ("Host-only adapter, '%1'",
-                            "details report (network)").arg (adapter.GetHostOnlyInterface()));
+                        attType = attType.arg(tr("Host-only adapter, '%1'",
+                            "details report (network)").arg(adapter.GetHostOnlyInterface()));
                     else if (type == KNetworkAttachmentType_Generic)
-                        attType = attType.arg (tr ("Generic, '%1'",
-                            "details report (network)").arg (adapter.GetGenericDriver()));
+                        attType = attType.arg(tr("Generic, '%1'",
+                            "details report (network)").arg(adapter.GetGenericDriver()));
                     else if (type == KNetworkAttachmentType_NATNetwork)
-                        attType = attType.arg (tr ("NAT network, '%1'",
-                            "details report (network)").arg (adapter.GetNATNetwork()));
+                        attType = attType.arg(tr("NAT network, '%1'",
+                            "details report (network)").arg(adapter.GetNATNetwork()));
                     else
-                        attType = attType.arg (gpConverter->toString (type));
+                        attType = attType.arg(gpConverter->toString(type));
 
                     p_text << UITextTableLine(tr("Adapter %1", "details report (network)").arg(adapter.GetSlot() + 1), attType);
@@ -476,8 +439,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -505,5 +467,4 @@
             return QString(":/serial_port_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -514,16 +475,16 @@
             for (ulong slot = 0; slot < count; slot++)
             {
-                CSerialPort port = m_machine.GetSerialPort (slot);
+                CSerialPort port = m_machine.GetSerialPort(slot);
                 if (port.GetEnabled())
                 {
                     KPortMode mode = port.GetHostMode();
-                    QString data = vboxGlobal().toCOMPortName (port.GetIRQ(), port.GetIOBase()) + ", ";
+                    QString data = vboxGlobal().toCOMPortName(port.GetIRQ(), port.GetIOBase()) + ", ";
                     if (mode == KPortMode_HostPipe ||
                         mode == KPortMode_HostDevice ||
                         mode == KPortMode_TCP ||
                         mode == KPortMode_RawFile)
-                        data += QString ("%1 (<nobr>%2</nobr>)")
-                                .arg (gpConverter->toString (mode))
-                                .arg (QDir::toNativeSeparators (port.GetPath()));
+                        data += QString("%1 (<nobr>%2</nobr>)")
+                                       .arg(gpConverter->toString(mode))
+                                       .arg(QDir::toNativeSeparators(port.GetPath()));
                     else
                         data += gpConverter->toString(mode);
@@ -535,8 +496,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -565,5 +525,4 @@
             return QString(":/parallel_port_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -575,7 +534,7 @@
                 if (port.GetEnabled())
                 {
-                    QString data = vboxGlobal().toLPTPortName (port.GetIRQ(), port.GetIOBase()) +
-                        QString (" (<nobr>%1</nobr>)")
-                        .arg (QDir::toNativeSeparators (port.GetPath()));
+                    QString data = vboxGlobal().toLPTPortName(port.GetIRQ(), port.GetIOBase()) +
+                        QString(" (<nobr>%1</nobr>)")
+                               .arg(QDir::toNativeSeparators(port.GetPath()));
                     p_text << UITextTableLine(tr("Port %1", "details report (parallel ports)").arg(port.GetSlot() + 1), data);
                 }
@@ -584,8 +543,7 @@
                 p_text << UITextTableLine(tr("Disabled", "details report (parallel ports)"), QString());
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
     return QVariant();
@@ -612,5 +570,4 @@
             return QString(":/usb_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -634,12 +591,11 @@
 
                     p_text << UITextTableLine(tr("Device Filters", "details report (USB)"), tr("%1 (%2 active)", "details report (USB)")
-                                                 .arg(coll.size()).arg(active));
+                                                                                              .arg(coll.size()).arg(active));
                 }
             }
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -668,5 +624,4 @@
             return QString(":/sf_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -680,8 +635,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -714,5 +668,4 @@
             return QString(":/state_running_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -833,8 +786,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -888,5 +840,5 @@
     }
 
-     m_pTimer = new QTimer(this);
+    m_pTimer = new QTimer(this);
 
     connect(m_pTimer, SIGNAL(timeout()), this, SLOT(sltProcessStatistics()));
@@ -906,5 +858,4 @@
             return QString(":/nw_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -928,8 +879,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
@@ -1103,5 +1053,4 @@
             return QString(":/hd_16px.png");
         }
-        break;
 
         case Qt::UserRole + 1:
@@ -1167,8 +1116,7 @@
             return QVariant::fromValue(p_text);
         }
-        break;
-
-        default:
-        break;
+
+        default:
+            break;
     }
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.h	(revision 65286)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/information/UIInformationDataItem.h	(revision 65287)
@@ -24,23 +24,12 @@
 
 /* GUI includes: */
-#include "UIThreadPool.h"
 #include "UIExtraDataDefs.h"
-#include "UIInformationDataItem.h"
 
 /* COM includes: */
 #include "COMEnums.h"
-#include "CGuest.h"
 #include "CMachine.h"
 #include "CConsole.h"
-#include "CDisplay.h"
-#include "CNetworkAdapter.h"
-#include "CMachineDebugger.h"
-#include "CMediumAttachment.h"
-#include "CSystemProperties.h"
-#include "CStorageController.h"
 
 /* Forward declarations: */
-class CNetworkAdapter;
-class QTextLayout;
 class UIInformationModel;
 
@@ -54,23 +43,20 @@
 public:
 
-    /** Constructs information data-item of type @a type.
-      * @param  machine  Brings the machine reference.
-      * @param  console  Brings the machine console reference.
-      * @param  pModel   Brings the information model this item belings to. */
-    UIInformationDataItem(InformationElementType type, const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
-
-    /** Destructs information data-item. */
-    ~UIInformationDataItem();
+    /** Constructs information data-item of type @a enmType.
+      * @param  machine  Brings the machine reference.
+      * @param  console  Brings the machine console reference.
+      * @param  pModel   Brings the information model this item belings to. */
+    UIInformationDataItem(InformationElementType enmType, const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
     /** Returns type of information data-item. */
-    InformationElementType elementType() const { return m_type; }
-
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    InformationElementType elementType() const { return m_enmType; }
+
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 
 protected:
 
     /** Holds the type of information data-item. */
-    InformationElementType m_type;
+    InformationElementType m_enmType;
 
     /** Holds the pixmap of information data-item. */
@@ -104,6 +90,6 @@
     UIInformationDataGeneral(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -122,6 +108,6 @@
     UIInformationDataSystem(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -140,6 +126,6 @@
     UIInformationDataDisplay(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -158,6 +144,6 @@
     UIInformationDataStorage(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -176,6 +162,6 @@
     UIInformationDataAudio(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -194,6 +180,6 @@
     UIInformationDataNetwork(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -212,6 +198,6 @@
     UIInformationDataSerialPorts(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -231,6 +217,6 @@
     UIInformationDataParallelPorts(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 #endif /* VBOX_WITH_PARALLEL_PORTS */
@@ -250,6 +236,6 @@
     UIInformationDataUSB(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -268,6 +254,6 @@
     UIInformationDataSharedFolders(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 
 protected slots:
@@ -291,6 +277,6 @@
     UIInformationDataRuntimeAttributes(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 };
 
@@ -309,6 +295,6 @@
     UIInformationDataNetworkStatistics(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 
 private slots:
@@ -323,20 +309,20 @@
 
     /** VM statistics counter data map. */
-    typedef QMap <QString, QString> DataMapType;
+    typedef QMap<QString, QString> DataMapType;
     /** VM statistics counter links map. */
-    typedef QMap <QString, QStringList> LinksMapType;
+    typedef QMap<QString, QStringList> LinksMapType;
     /** VM statistics counter struct. */
     struct CounterElementType { QString type; DataMapType list; };
 
     /** Holds the VM statistics counter names. */
-    DataMapType        m_names;
+    DataMapType   m_names;
     /** Holds the VM statistics counter values. */
-    DataMapType        m_values;
+    DataMapType   m_values;
     /** Holds the VM statistics counter units. */
-    DataMapType        m_units;
+    DataMapType   m_units;
     /** Holds the VM statistics counter links. */
-    LinksMapType       m_links;
+    LinksMapType  m_links;
     /** Holds the VM statistics update timer instance. */
-    QTimer            *m_pTimer;
+    QTimer       *m_pTimer;
 };
 
@@ -355,6 +341,6 @@
     UIInformationDataStorageStatistics(const CMachine &machine, const CConsole &console, UIInformationModel *pModel);
 
-    /** Returns data for item specified by @a index for the @a role. */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    /** Returns data for item specified by @a index for the @a iRole. */
+    virtual QVariant data(const QModelIndex &index, int iRole = Qt::DisplayRole) const;
 
 private slots:
@@ -372,20 +358,20 @@
 
     /** VM statistics counter data map. */
-    typedef QMap <QString, QString> DataMapType;
+    typedef QMap<QString, QString> DataMapType;
     /** VM statistics counter links map. */
-    typedef QMap <QString, QStringList> LinksMapType;
+    typedef QMap<QString, QStringList> LinksMapType;
     /** VM statistics counter struct. */
     struct CounterElementType { QString type; DataMapType list; };
 
     /** Holds the VM statistics counter names. */
-    DataMapType        m_names;
+    DataMapType   m_names;
     /** Holds the VM statistics counter values. */
-    DataMapType        m_values;
+    DataMapType   m_values;
     /** Holds the VM statistics counter units. */
-    DataMapType        m_units;
+    DataMapType   m_units;
     /** Holds the VM statistics counter links. */
-    LinksMapType       m_links;
+    LinksMapType  m_links;
     /** Holds the VM statistics update timer instance. */
-    QTimer            *m_pTimer;
+    QTimer       *m_pTimer;
 };
 
